@@ -20,7 +20,7 @@ from __future__ import print_function
 import numpy as np
 from numpy.testing import assert_almost_equal
 
-from statsmodels.regression.linear_model import OLS, WLS, GLS
+from statsmodels.regression.linear_model import OLS
 from statsmodels.regression.feasible_gls import GLSHet, GLSHet2
 from statsmodels.tools.tools import add_constant
 
